==> streamsnapper-0.1.1-py3-none-any.whl: streamsnapper/functions.py <==
# Built-in imports
from re import sub as re_sub
from unicodedata import normalize
from typing import Any, Dict, Optional, Callable


def get_value(data: Dict[Any, Any], key: Any, fallback_key: Any = None, convert_to: Callable = None, default_to: Optional[Any] = None) -> Any:
    """
    Get a value from a dictionary, with optional fallback key, conversion and default value.

    :param data: The dictionary to search for the key.
    :param key: The key to search for in the dictionary.
    :param fallback_key: The fallback key to search for in the dictionary if the main key is not found.
    :param convert_to: The type to convert the value to. If the conversion fails, return the default value. If None, return the value as is.
    :param default_to: The default value to return if the key is not found.
    :return: The value from the dictionary. If the key is not found, return the default value.
    """

    try:
        value = data[key]
    except KeyError:
        if fallback_key is not None:
            try:
                value = data[fallback_key]
            except KeyError:
                return default_to
        else:
            return default_to

    if convert_to is not None:
        try:
            value = convert_to(value)
        except (ValueError, TypeError):
            return default_to

    return value


def format_string(query: str, max_length: int = 128) -> Optional[str]:
    """
    Format a string to be used as a filename or directory name. Remove special characters, limit length and normalize the string.

    :param query: The string to be formatted.
    :param max_length: The maximum length of the formatted string. If the string is longer, it will be truncated.
    :return: The formatted string. If the input string is empty, return None.
    """

    if not query:
        return None

    normalized_string = normalize('NFKD', query).encode('ASCII', 'ignore').decode('utf-8')
    sanitized_string = re_sub(r'\s+', ' ', re_sub(r'[^a-zA-Z0-9\-_()[\]{}!$#+;,. ]', '', normalized_string)).strip()

    if len(sanitized_string) > max_length:
        cutoff = sanitized_string[:max_length].rfind(' ')
        sanitized_string = sanitized_string[:cutoff] if cutoff != -1 else sanitized_string[:max_length]

    return sanitized_string if sanitized_string else None

==> streamsnapper-0.2.0-py3-none-any.whl: streamsnapper/functions.py <==
# Built-in imports
from re import sub as re_sub
from unicodedata import normalize
from typing import Any, Dict, Optional, Callable


def get_value(
    data: Dict[Any, Any],
    key: Any,
    fallback_key: Optional[Any] = None,
    convert_to: Optional[Callable] = None,
    default_to: Optional[Any] = None,
) -> Any:
    """
    Get a value from a dictionary, with optional fallback key, conversion and default value.

    :param data: The dictionary to search for the key.
    :param key: The key to search for in the dictionary.
    :param fallback_key: The fallback key to search for in the dictionary if the main key is not found.
    :param convert_to: The type to convert the value to. If the conversion fails, return the default value. If None, return the value as is.
    :param default_to: The default value to return if the key is not found.
    :return: The value from the dictionary. If the key is not found, return the default value.
    """

    try:
        value = data[key]
    except KeyError:
        if fallback_key is not None:
            try:
                value = data[fallback_key]
            except KeyError:
                return default_to
        else:
            return default_to

    if convert_to is not None:
        try:
            value = convert_to(value)
        except (ValueError, TypeError):
            return default_to

    return value


def format_string(query: str, max_length: int = 128) -> Optional[str]:
    """
    Format a string to be used as a filename or directory name. Remove special characters, limit length and normalize the string.

    :param query: The string to be formatted.
    :param max_length: The maximum length of the formatted string. If the string is longer, it will be truncated.
    :return: The formatted string. If the input string is empty, return None.
    """

    if not query:
        return None

    normalized_string = (
        normalize('NFKD', query).encode('ASCII', 'ignore').decode('utf-8')
    )
    sanitized_string = re_sub(
        r'\s+', ' ', re_sub(r'[^a-zA-Z0-9\-_()[\]{}!$#+;,. ]', '', normalized_string)
    ).strip()

    if len(sanitized_string) > max_length:
        cutoff = sanitized_string[:max_length].rfind(' ')
        sanitized_string = (
            sanitized_string[:cutoff] if cutoff != -1 else sanitized_string[:max_length]
        )

    return sanitized_string if sanitized_string else None
